package java.rmi.server;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.io.Serializable;
import java.security.AccessController;
import java.security.SecureRandom;
import java.util.Random;
import sun.security.action.GetBooleanAction;

public final class ObjID implements Serializable {
   public static final int REGISTRY_ID = 0;
   public static final int ACTIVATOR_ID = 1;
   public static final int DGC_ID = 2;
   private long objNum;
   private UID space;
   private static final UID mySpace;
   private static final Random generator;
   private static final long serialVersionUID = -6386392263968365220L;

   public ObjID() {
      this.space = mySpace != null ? mySpace : new UID();
      this.objNum = generator.nextLong();
   }

   public ObjID(int var1) {
      this.space = new UID((short)0);
      this.objNum = (long)var1;
   }

   private ObjID(long var1, UID var3) {
      this.objNum = var1;
      this.space = var3;
   }

   public void write(ObjectOutput var1) throws IOException {
      var1.writeLong(this.objNum);
      this.space.write(var1);
   }

   public static ObjID read(ObjectInput var0) throws IOException {
      long var1 = var0.readLong();
      UID var3 = UID.read(var0);
      return new ObjID(var1, var3);
   }

   public int hashCode() {
      return (int)this.objNum;
   }

   public boolean equals(Object var1) {
      if (var1 != null && var1 instanceof ObjID) {
         ObjID var2 = (ObjID)var1;
         return this.objNum == var2.objNum && this.space.equals(var2.space);
      } else {
         return false;
      }
   }

   public String toString() {
      return "[" + (this.space.equals(mySpace) ? "" : this.space + ", ") + this.objNum + "]";
   }

   static {
      Boolean var0 = (Boolean)AccessController.doPrivileged(new GetBooleanAction("java.rmi.server.randomIDs"));
      boolean var1 = var0;
      if (var1) {
         generator = new SecureRandom();
         mySpace = null;
      } else {
         generator = new InsecureRandom((1)null);
         mySpace = new UID();
      }

   }
}
